Document class

Annotations

Constructors

Document({int id = 0, required String fileName, required String filePath, DateTime? createdAt, DateTime? updatedAt, int? fileSize, String? fileHash})
Document.empty()

Properties

chunks → ToMany<DocumentChunk>
final
content → String
no setter
createdAt ↔ DateTime
getter/setter pair
fileHash ↔ String?
getter/setter pair
fileName ↔ String
getter/setter pair
filePath ↔ String
getter/setter pair
fileSize ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt ↔ DateTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited