CactusCompletionParams class

Constructors

CactusCompletionParams({String? model, double? temperature, int? topK, double? topP, int maxTokens = 512, List<String> stopSequences = const ["<|im_end|>", "<end_of_turn>"], List<CactusTool>? tools, CompletionMode completionMode = CompletionMode.local, String? cactusToken, bool? forceTools})

Properties

cactusToken → String?
final
completionMode → CompletionMode
final
forceTools → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
maxTokens → int
final
model → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stopSequences → List<String>
final
temperature → double?
final
tools → List<CactusTool>?
final
topK → int?
final
topP → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited