CactusEmbeddingResult class

Constructors

CactusEmbeddingResult({required bool success, required List<double> embeddings, required int dimension, String? errorMessage})

Properties

dimension → int
final
embeddings → List<double>
final
errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited