CactusModel class

Constructors

CactusModel({required DateTime createdAt, required String slug, required String downloadUrl, required int sizeMb, required bool supportsToolCalling, required bool supportsVision, required String name, bool isDownloaded = false, int quantization = 8})
CactusModel.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → DateTime
final
downloadUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
isDownloaded ↔ bool
getter/setter pair
name → String
final
quantization → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeMb → int
final
slug → String
final
supportsToolCalling → bool
final
supportsVision → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited