SyncChange class

Sync incoming data event.

Properties

entity → Type
Entity type this change relates to.
final
entityId → int
Entity ID this change relates to.
final
hashCode → int
The hash code for this object.
no setterinherited
puts → List<int>
List of "put" (inserted/updated) object IDs.
final
removals → List<int>
List of removed object IDs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited