CactusConfig class

Constructors

CactusConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

cactusProKey ↔ String?
getter/setter pair
isInitialized → bool
no setter
isTelemetryEnabled ↔ bool
getter/setter pair
telemetryToken ↔ String?
getter/setter pair

Static Methods

setProKey(String token) → dynamic
setTelemetryToken(String token) → dynamic