CactusRAG class

Constructors

CactusRAG()
factory

Properties

chunkBox → Box<DocumentChunk>
no setter
chunkOverlap → int
no setter
chunkSize → int
no setter
documentBox → Box<Document>
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
store → Store
no setter

Methods

chunkContent(String content, {int? chunkSize, int? chunkOverlap}) → List<String>
close() → Future<void>
deleteDocument(int id) → Future<void>
getAllDocuments() → Future<List<Document>>
getDocumentByFileName(String fileName) → Future<Document?>
getStats() → Future<DatabaseStats>
initialize() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setChunking({required int chunkSize, required int chunkOverlap}) → void
setEmbeddingGenerator(EmbeddingGenerator generator) → void
storeDocument({required String fileName, required String filePath, required String content, int? fileSize, String? fileHash}) → Future<Document>
toString() → String
A string representation of this object.
inherited
updateDocument(Document document) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited